/* 
 * TCS Alignment Toolbox
 * 
 * Copyright (C) 2013, 2014
 * Benjamin Paaßen, Charlie Krüger, Georg Zentgraf
 * AG Theoretical Computer Science
 * Centre of Excellence Cognitive Interaction Technology (CITEC)
 * University of Bielefeld
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.citec.tcs.alignment;

/**
 * Identifies a position in a two-dimensional matrix.
 *
 * @author Benjamin Paassen - bpaassen@techfak.uni-bielefeld.de
 */
public class MatrixCoordinate {

    private final int i;
    private final int j;
    //The number of rows
    private final int m;

    /**
     *
     * @param i the row index.
     * @param j the column index.
     * @param m the number of rows. This is needed to define a unique hash code.
     */
    public MatrixCoordinate(int i, int j, int m) {
        this.i = i;
        this.j = j;
        this.m = m;
    }

    /**
     *
     * @return the row index.
     */
    public int getI() {
        return i;
    }

    /**
     *
     * @return the column index.
     */
    public int getJ() {
        return j;
    }

    /**
     *
     * @return the number of rows.
     */
    public int getM() {
        return m;
    }

    /**
     * The HashCode given here defines the MatrixCoordinate uniquely as i*m + j,
     * giving an bijective mapping of HashCodes to actual MatrixCoordinates.
     *
     * @return the unique HashCode of this MatrixCoordinate.
     */
    @Override
    public int hashCode() {
        return i * m + j;
    }

    /**
     * {@inheritDoc }
     */
    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final MatrixCoordinate other = (MatrixCoordinate) obj;
        if (this.i != other.i) {
            return false;
        }
        if (this.j != other.j) {
            return false;
        }
        if (this.m != other.m) {
            return false;
        }
        return true;
    }

    /**
     * {@inheritDoc }
     */
    @Override
    public String toString() {
        return "(" + i + "," + j + ")";
    }
}
