/* 
 * TCS Alignment Toolbox
 * 
 * Copyright (C) 2013, 2014
 * Benjamin Paaßen, Charlie Krüger, Georg Zentgraf
 * AG Theoretical Computer Science
 * Centre of Excellence Cognitive Interaction Technology (CITEC)
 * University of Bielefeld
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.citec.tcs.alignment;

/**
 * This defines the possible types of operations that may be used in an
 * alignment within this Toolbox. Remember: An Alignment is defined as a
 * sequence of Operations to transform the left input sequence into the right
 * one. The more operations are needed, the more the sequences are dissimilar
 * (roughly).
 *
 * Please note that not all AlignmentAlgorithms have to make use of all
 * operations. Some only use Replacements (DTW-style), most only Replacements,
 * Insertions and Deletions (Global Alignment in a Needleman-Wunsch-Style).
 *
 * Up until Version 1.0, Skip-Alignments (local Alignments) are not yet
 * implemented.
 *
 * @author Benjamin Paassen - bpaassen@techfak.uni-bielefeld.de
 */
public enum OperationType {

    /**
     * A replacement of one node in the left input sequnce with one in the right
     * input sequence. Please note that this does not mean a bad thing: The
     * replacement Operation is used for perfectly matching nodes as well as for
     * mismatching nodes.
     */
    REPLACEMENT,
    /**
     * The deletion of one node in the left sequence.
     */
    DELETION,
    /**
     * The insertion of one node from the right sequence into the left sequence.
     */
    INSERTION,
    /**
     * The deletion of one node in the left sequence in the beginning or end of
     * the alignment.
     */
    SKIPDELETION,
    /**
     * The insertion of one node from the right sequence into the left sequence
     * in the beginning or end of the alignment.
     */
    SKIPINSERTION;
}
