/* 
 * TCS Alignment Toolbox
 * 
 * Copyright (C) 2013, 2014
 * Benjamin Paaßen, Charlie Krüger, Georg Zentgraf
 * AG Theoretical Computer Science
 * Centre of Excellence Cognitive Interaction Technology (CITEC)
 * University of Bielefeld
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.citec.tcs.alignment.visualization;
//package de.unibi.citec.fit.dfgvis;

import static de.unibi.citec.tcs.alignment.visualization.Keywords.IMAGE_KEYWORD;
//import static de.unibi.citec.fit.dfgvis.Keywords.IMAGE_KEYWORD;
import de.unibi.citec.tcs.alignment.sequence.Node;
import de.unibi.citec.tcs.alignment.sequence.Value;
import java.io.File;

/**
 *
 * @author ckrueger
 */
public class HTImageFromPath extends AbstractHTMLTransformerFromPath {

    /**
     * Attention: when using this constructor, you have to call 
     * setFiles() manually.
     * @param keyword the keyword, as it should appear in the table.
     */
    public HTImageFromPath(final String keyword) {
        super(keyword);
    }
    
    /**
     * Initializes given files or folders. 
     * @param keyword the keyword, as it should appear in the table.
     * @param files_or_folders Paths to source code files or 
     *      a directory/directories containing such files.
     */
    public HTImageFromPath(final String keyword, final String[] files_or_folders) {        
        super(keyword, files_or_folders);
    }

    /**
     * Initializes given folder. 
     * @param keyword the keyword, as it should appear in the table.
     * @param folder Paths a directory containing such source code files.
     */
    public HTImageFromPath(final String keyword, final String folder) {        
        super(keyword, folder);
    }

    /**
     * Initializes given files or folders. 
     * @param keyword the keyword, as it should appear in the table.
     * @param files_or_folders Source code files or 
     *      a directory/directories containing such files.
     */
    public HTImageFromPath(final String keyword, final File[] files_or_folders) {        
        super(keyword, files_or_folders);
    }

    /**
     * Initializes given folder. 
     * @param keyword the keyword, as it should appear in the table.
     * @param folder A directory containing such source code files.
     */
    public HTImageFromPath(final String keyword, final File folder) {        
        super(keyword, folder);
    }

    /**
     * Takes an image file from the given node and generates a
     * corresponding HTML representation.
     * @param node a node from some sequence that can be transformed according
     * to this ExternalContent.
     * @return A HTML representation of the extracted content. 
     */
    @Override
    public String getHTMLforNode(Node node) {
        final StringBuilder content = new StringBuilder();
        final Value val = node.getValue(IMAGE_KEYWORD);
        if (val == null) {
            return "<>";
        }
        final String img = val.toString();
        
        if (!getFiles().containsKey(img)) {
            Boolean found = Boolean.FALSE;
            Integer i = 0;
            while (!found && getFiles().containsKey("dir" + i.toString())) {
                for (File file : getFiles().get("dir" + i.toString()).listFiles()) {
                    if (file.getName().equals(img)) {
                        if (!(file.exists() && file.canRead())) 
                            throw new RuntimeException("Image " + img + " does not exist or"
                            + "is not executable");
                        getFiles().put(img, file);
                        found = Boolean.TRUE;
                        break;
                    }
                }
                i++;
            }
            
            if (!found) {
                throw new RuntimeException("There is no path for image " + img + " given");
            }
        }        
        
        content.append("<img src=\"");
        content.append(getFiles().get(img).getAbsolutePath());
        content.append("\" title=\"");
        content.append(img);
        content.append("\" />");
        
        return content.toString();
    }
    
}
